@@ -57,7 +57,9 @@ class _Task:
 		self.args = []
 		self.defaults = {}
 		self.requirements = ()
+		self.generates = ()
 		self.valid = None
+		self.method = False
 
 	def __call__(self, *args, **kwargs):
 		if self.requirements:
@@ -67,7 +69,10 @@ class _Task:
 
 		try:
 			require(*self.requirements)
-			self.func(*args, **kwargs)
+			if self.method:
+				self.func(self, *args, **kwargs)
+			else:
+				self.func(*args, **kwargs)
 		except _AbortException, ex:
 			self.valid = False
 			self.__print('abort', self, ex.message)
@@ -157,6 +162,11 @@ def private(func):
 
 	return func
 
+def method(func):
+	func = task(func)
+	func.method = True
+	return func
+
 def suppress(*messages):
 	def wrapper(func):
 		func = task(func)
@@ -176,13 +186,10 @@ def requires(*requirements):
 def alias(*aliases):
 	def wrapper(func):
 		global DICT
-
 		func = task(func)
 		func.aliases = aliases
-
 		for alias in aliases:
 			DICT[alias] = func
-
 		return func
 
 	return wrapper
@@ -200,6 +207,7 @@ def generates(*files):
 	def wrapper(func):
 		global GENERATES
 		func = task(func)
+		func.generates = files
 		GENERATES += list(files)
 		return func
 
